import { isPlainObject } from './util.js';
// 2xx
export const OK = (body, headers = {}) => {
    const init = { status: 200, headers };
    return isPlainObject(body) || Array.isArray(body)
        ? JSON(body, init)
        : new Response(body, init);
};
export const Created = (body = '', headers = {}) => {
    const init = { status: 201, headers };
    return isPlainObject(body) || Array.isArray(body)
        ? JSON(body, init)
        : new Response(body, init);
};
export const Accepted = (headers = {}) => new Response('', { status: 202, headers });
export const NoContent = (headers = {}) => new Response('', { status: 204, headers });
// 3xx
export const Redirect = (url, status = 302) => Response.redirect(url, status);
// 4xx
export const BadRequest = (body = '') => {
    const init = { status: 400 };
    return isPlainObject(body) || Array.isArray(body)
        ? JSON(body, init)
        : new Response(body, init);
};
export const Unauthorized = (body = '') => {
    const init = { status: 401 };
    return isPlainObject(body) || Array.isArray(body)
        ? JSON(body, init)
        : new Response(body, init);
};
export const Forbidden = (body = '') => {
    const init = { status: 403 };
    return isPlainObject(body) || Array.isArray(body)
        ? JSON(body, init)
        : new Response(body, init);
};
export const NotFound = (headers = {}) => new Response('Not Found', { status: 404, headers });
export const MethodNotAllowed = () => new Response('', { status: 405 });
export const NotAcceptable = () => new Response('', { status: 406 });
export const Conflict = (body = '') => {
    const init = { status: 409 };
    return isPlainObject(body) || Array.isArray(body)
        ? JSON(body, init)
        : new Response(body, init);
};
// 5xx
export const InternalServerError = (body = '') => {
    const init = { status: 500 };
    return isPlainObject(body) || Array.isArray(body)
        ? JSON(body, init)
        : new Response(body, init);
};
// Special case (type-related)
export const HTML = (body, headers = {}) => new Response(body, {
    status: 200,
    headers: { ...headers, 'Content-Type': 'text/html; charset=utf-8' },
});
export const Plain = (body, init) => new Response(body, init);
// FIXME why `body` cannot be `PlainObject` -> ask Michal
export const JSON = (body, { status, headers }) => {
    const json = globalThis.JSON.stringify(body, null, 2);
    return new Response(json, {
        status,
        headers: { ...headers || {}, 'Content-Type': 'application/json; charset=utf-8' },
    });
};
