export declare type PlainObject = Record<string, unknown> | PlainObject[];
export declare type MaybePromise<T> = T | Promise<T>;
export interface Context {
}
export interface Params {
    [name: string]: string | number | boolean | Params;
}
export interface RequestExtension {
    method: HTTPMethod;
    params: Params;
    files: {
        [name: string]: File;
    };
}
export declare type _Request = Request & RequestExtension;
export declare type Handler = <T extends Context>(request: Request & RequestExtension, context: T) => MaybePromise<Response>;
export declare type Middleware = (handler: Handler) => Handler;
export declare type Pipeline = [...Middleware[], Handler];
export declare type ReversedPipeline = [Handler, ...Middleware[]];
export interface Meta {
    summary?: string;
    description?: string;
    parameters?: Array<unknown>;
    responses?: Record<string, unknown>;
}
export interface RoutePaths {
    [name: string]: any;
}
export interface RouteOptions {
    middleware?: Middleware[];
    meta?: Meta;
}
export interface HandlerMapping {
    GET?: Handler | Pipeline;
    POST?: Handler | Pipeline;
    PUT?: Handler | Pipeline;
    PATCH?: Handler | Pipeline;
    DELETE?: Handler | Pipeline;
    middleware?: Middleware[];
    meta?: Meta;
}
export declare type Route = [string, HandlerMapping | Handler | Pipeline, Route?];
export declare type Routes = Route[];
export declare const HTTPMethod: {
    readonly GET: "GET";
    readonly POST: "POST";
    readonly PUT: "PUT";
    readonly PATH: "PATCH";
    readonly HEAD: "HEAD";
    readonly OPTIONS: "OPTIONS";
    readonly DELETE: "DELETE";
    readonly ANY: "ANY";
};
export declare type HTTPMethod = typeof HTTPMethod[keyof typeof HTTPMethod];
export interface HandlerParams {
    handler: Handler;
    names: string[];
}
export interface HandlerParamsMap {
    [method: string]: HandlerParams;
}
export interface KeyValue {
    name: string;
    value: string;
}
export interface Options {
    port: number;
}
export declare const Server: (routes: Routes, options?: Options) => {
    port: number;
    fetch: (request: Request, connInfo: any) => MaybePromise<Response>;
};
export { Router } from './router.js';
